pub fn parse_assert_input(
request: &RpcRequest,
) -> Result<AssertInput, RpcResponse>Expand description
Parse AssertInput from RpcRequest.
The assert endpoint expects a condition string in the format “type:value”.
pub fn parse_assert_input(
request: &RpcRequest,
) -> Result<AssertInput, RpcResponse>Parse AssertInput from RpcRequest.
The assert endpoint expects a condition string in the format “type:value”.