pub enum DomainElementType {
Button,
Input,
Checkbox,
Radio,
Select,
MenuItem,
ListItem,
Spinner,
Progress,
Link,
}Variants
Implementations
Sourceimpl DomainElementType
impl DomainElementType
pub fn as_str(&self) -> &'static str
Sourcepub fn is_interactive(&self) -> bool
pub fn is_interactive(&self) -> bool
Returns true if this element type represents an interactive element.
Sourcepub fn accepts_input(&self) -> bool
pub fn accepts_input(&self) -> bool
Returns true if this element type can receive text input.
Sourcepub fn is_toggleable(&self) -> bool
pub fn is_toggleable(&self) -> bool
Returns true if this element type can be toggled.