pub struct RpcResponse { /* private fields */ }Implementations
Sourceimpl RpcResponse
impl RpcResponse
pub fn success(id: u64, result: Value) -> Self
pub fn error(id: u64, code: i32, message: &str) -> Self
pub fn error_with_context( id: u64, code: i32, message: &str, session_id: Option<&str>, ) -> Self
Sourcepub fn error_with_data(
id: u64,
code: i32,
message: &str,
error_data: ErrorData,
) -> Self
pub fn error_with_data( id: u64, code: i32, message: &str, error_data: ErrorData, ) -> Self
Create an error response with structured ErrorData.
This is the preferred method for domain errors as it provides machine-readable context for AI agents.
Sourcepub fn domain_error(
id: u64,
code: i32,
message: &str,
category: &str,
context: Option<Value>,
suggestion: Option<String>,
) -> Self
pub fn domain_error( id: u64, code: i32, message: &str, category: &str, context: Option<Value>, suggestion: Option<String>, ) -> Self
Create an error response from a DomainError-like interface.
This helper constructs a fully structured error response with:
- Semantic error code
- Human-readable message
- Category, retryable flag, context, and suggestion
pub fn action_success(id: u64) -> Self