Semantic error codes for JSON-RPC domain errors.
Error codes follow the JSON-RPC 2.0 specification:
- -32700 to -32600: Reserved protocol errors
- -32000 to -32099: Server errors (we use -32001 to -32020 for domain errors)
Enums
- Error
Category - Error category for programmatic handling by AI agents.
Constants
- COMMAND_
NOT_ FOUND - DAEMON_
ERROR - ELEMENT_
NOT_ FOUND - GENERIC_
ERROR - INVALID_
KEY - LOCK_
TIMEOUT - NO_
ACTIVE_ SESSION - PERMISSION_
DENIED - PERSISTENCE_
ERROR - PTY_
ERROR - SESSION_
LIMIT - SESSION_
NOT_ FOUND - WAIT_
TIMEOUT - WRONG_
ELEMENT_ TYPE
Functions
- category_
for_ code - Returns the error category for a given error code.
- is_
retryable - Returns whether an error code represents a retriable operation.